@@ -5,9 +5,18 @@ Tests for model classes - mirrors Java model test patterns.
 import pytest
 
 from pdfdancer import (
-    ObjectRef, Position, ObjectType, Font, Color, Image, Paragraph, BoundingRect,
-    PositionMode, ShapeType
+    BoundingRect,
+    Color,
+    Font,
+    Image,
+    ObjectRef,
+    ObjectType,
+    Paragraph,
+    Position,
+    PositionMode,
+    ShapeType,
 )
+
 # Import Point class for tests
 from pdfdancer.models import Point
 
@@ -133,13 +142,19 @@ class TestColor:
         Color(0, 128, 255)
 
         # Invalid values should raise ValueError
-        with pytest.raises(ValueError, match="Color component must be between 0 and 255"):
+        with pytest.raises(
+            ValueError, match="Color component must be between 0 and 255"
+        ):
             Color(-1, 0, 0)
 
-        with pytest.raises(ValueError, match="Color component must be between 0 and 255"):
+        with pytest.raises(
+            ValueError, match="Color component must be between 0 and 255"
+        ):
             Color(0, 256, 0)
 
-        with pytest.raises(ValueError, match="Color component must be between 0 and 255"):
+        with pytest.raises(
+            ValueError, match="Color component must be between 0 and 255"
+        ):
             Color(0, 0, 300)
 
 
